DidController

Enum DidController 

pub enum DidController {
    One(String),
    Many(Vec<String>),
}
The controller property — either a single DID string or a set of DIDs.

Per W3C DID Core 5.1.2, the controller can be one or more DID strings. When multiple DIDs are listed, each controller independently has the authority to update or deactivate the subject DID.

Variants



One(String)



Many(Vec<String>)

Implementations

Source

impl DidController

pub fn iter(&self) -> impl Iterator<Item = &str>

Iterate over all controller DIDs.

pub fn contains(&self, did: &str) -> bool

Returns true if did is listed as a controller.