pub fn blake3_keyed_hash_auto(key: &[u8; 32], region: &[u8]) -> HashExpand description
Compute a keyed BLAKE3 hash, automatically dispatching to
update_rayon when the input is large enough to benefit. See
BLAKE3_RAYON_THRESHOLD.
pub fn blake3_keyed_hash_auto(key: &[u8; 32], region: &[u8]) -> HashCompute a keyed BLAKE3 hash, automatically dispatching to
update_rayon when the input is large enough to benefit. See
BLAKE3_RAYON_THRESHOLD.