Blake3Signer

Struct Blake3Signer 

pub struct Blake3Signer { /* private fields */ }
BLAKE3 digest signer for high-throughput self-certifying content.

Uses signature type code SIGNATURE_TYPE_DIGEST_BLAKE3_PLAIN (6), reserved on the NDN TLV SignatureType registry. Analogous to DigestSha256 (type 0) but uses BLAKE3, which is 3–8× faster on modern CPUs due to SIMD parallelism.

The “signature” is a 32-byte BLAKE3 hash of the signed region. There is no secret key — this provides integrity (content addressing) but not authentication. For keyed BLAKE3 (authentication), use Blake3KeyedSigner, which uses a distinct type code so verifiers cannot be downgraded from keyed to plain mode via a substitution attack.

Implementations

Source

impl Blake3Signer

pub fn new(key_name: Name) -> Self